@@ -3,7 +3,7 @@
 @File    :   __init__.py
 @Time    :   2021/10/06 18:21:15
 @Author  :   Ming Ding 
-@Contact :   dm18@mail.tsinghua.edu.cn
+@Contact :   dm18@mails.tsinghua.edu.cn
 '''
 
 # here put the import lib
